@@ -1,4 +1,5 @@
 require 'librarian/action/resolve'
+require 'librarian/puppet/resolver'
 
 module Librarian
   module Puppet
@@ -15,6 +16,10 @@ module Librarian
           end
         end
 
+        def resolver
+          Resolver.new(environment)
+        end
+
       end
     end
   end
