@@ -1,7 +1,7 @@
 require "librarian/environment"
 require "librarian/puppet/dsl"
 require "librarian/puppet/source"
-require "librarian/puppet/lockfile/parser"
+require "librarian/puppet/lockfile"
 
 module Librarian
   module Puppet
@@ -11,6 +11,14 @@ module Librarian
         "puppet"
       end
 
+      def lockfile
+        Lockfile.new(self, lockfile_path)
+      end
+
+      def ephemeral_lockfile
+        Lockfile.new(self, nil)
+      end
+
       def tmp_path
         part = config_db["tmp"] || ".tmp"
         project_path.join(part)
@@ -46,6 +54,9 @@ module Librarian
         config_db['mode'] == 'local'
       end
 
+      def use_v1_api
+        config_db['use-v1-api']
+      end
     end
   end
 end
